## Metadata for SRS zooplankton sampling data


> Corresponds to `SRS_Data.xlsx`

### First tab - Condition Data - represents environmental data recorded from 
adjacent to the depth gauge (except when water depth was too great) for each 
wetland on each sampling occasion. Corresponds to `environmentalVars.csv`.

## Condition Data columnn headers

Samp_ID = unique number identifing each record
Bay = number identity of each sampled bay; these are listed in Schalles et al. (1989)
Year = year of data collection
Month = month of data collection, represented numerically
Date = date of data collection
Day = chronological day of data collection beginning January 1, 2009
Temp = water temperature (C) approximately 5 cm below water surface
Cond = specific conductivity (mS/m) pproximately 5 cm below water surface
pH = pH of water sample, measured in lab
NH4 = ammonium concentration, measured in lab
NO3 = nitrate concentration, measured in lab
Depth = depth (cm) recorded at depth gauge, depths written in red are estimated
	depths from when the depth gauge could not be reached due to high water
Comments = general commments
Depth Comments = alternate depth measurements and conversions to estimate depth gauge
	depths from when water was too deep to reach depth gauge

#### Second tab - Sample Data - data recorded for each individual sample. Corresponds to `samplingInfo.csv`.

## Sample Data column headers

Bay = number identity of each sampled bay; these are listed in Schalles et al. (1989)
Samp_ID = unique number for each sampling event by bay by date; all samples within a
	bay on the same date have the same number; matches with 'Samp_ID' from the
	'Conditions Data' tab
Year = year of sample collection
Month = month of sample collection, represented numerically
Date = date of sample collection
Day = chronological day of sample collection beginning January 1, 2009
Sample = identifies whether a sample was taken (Y) or not (N)
Type = identifies the type of sample taken
		Quan = quantitative sample taken with the tube sampler
		Qual = qualitative sample taken by submerging sample bottle
Method = method of identifying sample localities
		Standard = sampling at generated random points
		Trans = sampling in transect fashion when water levels were low
Sample_num = number (1-5) idenitifying each sample within a bay per date
Lat = latitude of sample location in seconds as a decimal (e.g. '43' would be
	0.043, '547' would be 0.547). Degrees and minutes for each bay given below
		3 = 33 20'
		4 = 33 20'
		7 = 33 17'
		9 = 33 17'
		11 = 33 18'
		25 = 33 15'
		26 = 33 15'
		40 = 33 16'
		41 = 33 16'
		44 = 33 15'
		66 = 33 19'
		67 = 33 19'
		78 = 33 17'
		79 = 33 17'
		80 = 33 17'
		176 = 33 13'
Lon = longitude of sample location in seconds as a decimal (e.g. '43' would be
	0.043, '547' would be 0.547). Degrees and minutes for each bay given below
		3 = 81 40'
		4 = 81 41'
		7 = 81 46'
		9 = 81 45'
		11 = 81 45'
		25 = 81 45'
		26 = 81 45'
		40 = 81 36'
		41 = 81 36'
		44 = 81 36'
		66 = 81 28'
		67 = 81 28'
		78 = 81 29'
		79 = 81 29'
		80 = 81 29'
		176 = 81 44'
Sample_Dp = depth of sample (cm)
Veg = general vegetation type, open water (OW) or vegetated (V)
Veg_type = specific vegetation class
		O = open water, substate bare or not visible
		LL = open water, leaf litter substrate
		TH = open water, substrate of thatch (decaying emergent vegetation)
		ALG = open water, substrate of filamentous algae
		FL = floating-leaf vegetation (water lilies, duckweed)
		EM = emergent vegetation (grasses and sedges)
		SB = submerged-leaf vegetation
Comments = general commments

#### Third tab - Zooplankton Data - organisms collected within a sample. Corresponds to `zoopData.csv`.

## Zooplankton Data column headers

Samp_ID = unique number for each sampling event by bay by date; all samples within a
	bay on the same date have the same number; matches with 'Samp_ID' from the
	'Conditions Data' and 'Sample Data' tabs
Bay = number identity of each sampled bay; these are listed in Schalles et al. (1989)
Year = year of sample collection
Month = month of sample collection, represented numerically
Date = date of sample collection
Day = chronological day of sample collection beginning January 1, 2009
Sample = number (1-5) idenitifying each sample within a bay per date
Sample_Dp = depth of sample (cm)
Volume = volume of water sampled (ml)
Flag = Y/N whether presence of taxa indicated is suspicious and might have been transferred from previous sample location (this is not often used)
Taxa = taxonomic identity of organism
Abund = overall number of taxon collected
Male = number of males collected
Female = number of females collected (calanoids only)
Repro = number of egg bearing (copepods) or parthenogenetic individuals (cladocerans)
Eph = number of ephippial females (cladocerans only)
Density = number per liter
Notes = comments, usually indicating whether a sample was subsampled to estimate abundance


#### Fouth tab - Taxa - all the taxa identified and general status or definition given
	in the commments header

#### Fifth tab - Taxonomy - taxonomic status of all microcrustacean zooplankton collected;
	note that species name given is not necessarily the same as in the 'Taxa' tab, as
	conciseness was preferable when listing species within samples

## Taxonomy colummn headers

Species = species name
Taxonomic Status = discussion of the taxonomic status of each species with references to
	appropriate literature
Type locality = locality where type specimen was collected; North American populations of species with type localities outside the Nearctic or Neotropics need further study to clarify their status here.


> Corresponds to `interactionMatrixDensity.csv`

### Table showing the density (ind/L) of individual taxa on various sampling dates. Derived from analysis of "Zooplankton Data"

## InteractionMatrix.csv columnn headers

Row Label = Bay_Day as identifier for each sample combination
[Species Names] = The density of individuals of this species averaged over the samples for this event. ind/L. Each sampling date may have had multiple samples counted (i.e. Sample_num 1:5)


> Corresponds to directory 'bay-data'

###Each file is the subset of 'Zooplankton Data' worksheet including only data for that bay


> Corresponds to directory 'heatmap_data-prep'

###The .tsv files are produced by from 'interactionMatrixDensity.csv' via R script 'zoovis-tables.R'. These are then used to draw the Species distribution and Species cooccurrence plots.
