# script to generate tables for ZooVis heat maps
# created by John Drake and Reni Kaul (7 April 2017)

d <- read.csv('interactionMatrixDensity.csv', colClasses = c('factor', rep('numeric',87)))
d[is.na(d)] <- 0#replace NA with zero

#d <- read.csv('interactionMatrix.csv', colClasses = c('factor', rep('numeric',87)))

# 0. Create bay identifier
bay <- substr(as.character(d[,1]),1,2)
bay[grep('_', bay)] <- substr(bay[grep('_', bay)],1,1)
bay <- as.numeric(bay)

# Species by bay table

# 1. Aggregate (sum) counts for each species by bay

counts <- aggregate(d[,2:dim(d)[2]], by=list(bay), FUN=sum)

# 2. Reformat to three columns with Bay ID, Species ID, Count (or 0/1)

c2  <- counts[,-1]
row.names(c2)  <- counts[,1] 

sp.id <- rep(1:length(c2), each=length(unique(bay))) #add in number id for d3 array set up
bay.id <- rep(1:dim(c2)[1], times=dim(c2)[2]) #add in number id for d3 array set up

table1 <- reshape(c2, times=names(c2), timevar = "Species", ids=row.names(c2), direction='long', varying=list(names(c2)))
table1 <- data.frame(species_id=sp.id, bay_id=bay.id, species = table1[,1],bay= table1[,3], count=table1[,2], occur=ifelse(table1[,2]>0,1,0))

# 3. Make species names pretty
s1 <- gsub("\\.", " ", table1$species, perl=TRUE)
#s1 <- gsub("cf ", "cf", s1, perl=TRUE)
table1$species  <- s1


# Species co-occurrence table

# 1. Multiply (outer vector product) counts of species for all pairs of species -- test output > 0 -- all zeros are non-co-occurrence

out <- outer(1:87, 1:87, FUN=Vectorize(function(i,j) sum(c2[,i]*c2[,j]>0)))

# 2. Reformat

species <- names(c2)
species <- gsub("\\.", " ", species, perl=TRUE)
#species <- gsub("cf ", "cf", species, perl=TRUE)

table2 <- matrix(rep(NA,5*87*88/2), ncol=5)
k <- 1
for(i in 1:87){
  for(j in i:87){
    table2[k, 1] <- species[i]
    table2[k, 2] <- i
    table2[k, 3] <- species[j]
    table2[k, 4] <- j
    table2[k, 5] <- out[i,j]
    k <- k+1
  }
}

table2 <- data.frame(row_idx=table2[,1],row.num=as.numeric(table2[,2]),col_idx=table2[,3],col.num=as.numeric(table2[,4]),count=as.numeric(table2[,5]))
table3 <- data.frame(row_idx=table2[,1],row.num=as.numeric(table2[,2]),col_idx=table2[,3],col.num=as.numeric(table2[,4]),count=as.numeric(table2[,5]),cooccur=1*(table2[,5]>0))
table3$cooccur<- ifelse(table3$row_idx==table3$col_idx,2,table3$cooccur)

#write csv
write.table(table1, "Sp_by_Bay.tsv", sep='\t',row.names=FALSE)
write.table(table2, file="Sp_by_Sp_count.tsv", sep='\t',row.names=FALSE)
write.table(table3, "Sp_by_Sp.tsv", sep="\t", row.names=FALSE)
