##Script to produce interaction matrix from SRS zooplankton data
##Should produce a file with each row representing a bay by date combination and each column a species

zoopData<-read.csv("zoopData.csv",header=T)
list.species<-read.csv("SRS_Zoop_species_groups.csv")

srs.data<-zoopData[,1:18] #Removes blank columns
all.species<-unique(srs.data$taxa)
species<-as.character(list.species$taxa)
matches<-all.species %in% species #Should have 87 matches, i.e. all list.species should appear in zoopData

#Clean up labels
s1<- gsub("\\.", "", srs.data$taxa, perl=TRUE)
#s1 <- gsub("cf", "cf ", s1, perl=TRUE)
srs.data$taxa<-s1
s2<- gsub("\\.", "", species, perl=TRUE)
#s2 <- gsub("cf", "cf ", s2, perl=TRUE)
species<-sort(s2)
matches<-species %in% unique(srs.data$taxa) #Should still have 87 matches

zoops.only<-srs.data[srs.data$taxa %in% species,]
bay_day<-paste(zoops.only$bay,"_",zoops.only$day,sep="")
zoops.only<-cbind(zoops.only,bay_day)
#Remove bay 176 from the displayed data, see Zokan 2015 for explanation
zoops.only<-zoops.only[which(zoops.only$bay!=176),]

#create output table
interaction.matrix<-matrix(nrow=length(unique(zoops.only$bay_day)),ncol=length(species))
rownames(interaction.matrix)<-sort(unique(zoops.only$bay_day))
colnames(interaction.matrix)<-species
for (i in 1:dim(interaction.matrix)[1]){
  for (j in 1:dim(interaction.matrix)[2]){
    sub<-zoops.only[which(zoops.only$bay_day==rownames(interaction.matrix)[i] &
                            zoops.only$taxa==colnames(interaction.matrix)[j]),]
    density<-sum(sub$abund)/sum(sub$volume)
    interaction.matrix[i,j]<-density
  }
}

write.csv(interaction.matrix,"interactionMatrixDensity.csv")
